#!/bin/sh
#
# Purpose:
#   Obsoletes study recursively in the dotcom and in the archive.
#
# Synopsis:
#   obsolete.sh <study instance uid> [<except IP>]
#
# Arguments:
#    study instance uid : Study Instance UID of the study to be obsoleted
#    except device      : ID of the device the obsolete request received from
#
# Description:
#
#   Moves the study directory to $TMP/obsoleted and removes database entries for
# the study. If internal (or HSM) archive is configured for the server, the study
# will also be obsoleted in the archive by calling $ARCHIVE_HOME/obs.sh.
#
# obsolete.sh will also send obsolete request to parent and child servers where
# the study exists, except the server from where the obsolete request was
# received (except device).
#
# A flag file will be create in $TMP to avoid registering/sending DICOM
# objects for the study has been obsoleted. The name of the flag file is
# nuked.<study instance uid> (See nukestudy.sh)
#
# Note:
#   obsolete.sh will use setstudy.prp to be the obsolation spread in the dotcom.
#
# ENDDOC
#
#  Last Modified by   : $Author$
#  Last modificied at : $Date$
#  RCS File Name      : $RCSfile$
#  RCS Revision       : $Revision$
#  Locked by          : $Locker$
#  Symbolic name      : $Name$
#  State              : $State$
#

. $HOME/etc/setenv.sh

study=$1
exceptDevice=$2


if [ -z "$study" ] ; then
	echo "Missing parameter"
	echo "usage:"
	echo "   obsolete.sh <study>"
	exit 1
fi


[ -f "$CONF/taskd.rc" ] && . $CONF/taskd.rc

params="-s \"$study\""
[ -n "$exceptDevice" ] && params="$params -H \"$exceptDevice\""
[ -n "$LOG_USER" ] && params="$params -u \"$LOG_USER\""


# echo "0 ${CASES_HOME#$HOME/component/}.ObsoleteStudy $params" 
$TASKD_HOME/runjavacmd -c "0 ${CASES_HOME#$HOME/component/}.ObsoleteStudy $params" -p $JAVA_SERVER_PORT

exit $?

