#!/bin/sh
#
# Reindex study
#
# Usage:
#    reindexStudy.sh [-r | -e] [-d] [-b] [-m] <study>
#
# Options:
#
# Reindex Mode (the last one on the command line will be used)
#   -e        : called for existing file: reindex only
#   -r        : reindex with autoforward, put to archive, ... [default]
#
# Other options:
#   -d        : call Dcreg directly instead of via taskd
#   -b        : start reindex in the background
#   -m        : reindex only objects missing from the database
#
# argument(s):
#   <study>   : Study Instance UID of the study to be reindexed
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

Options=""
ReindexOption="-r"
BackGround="false"
MissingOnly="false"


while getopts 'erdbm' OPT; do
	case $OPT in
	e) ReindexOption="-e" ;;
	r) ReindexOption="-r" ;;
	d) Options="$Options -d" ;;
	m) MissingOnly="true" ;;
	b) BackGround="true" ;;
	*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

shift $(($OPTIND-1))

Study="$1"

[ -z "$Study" ] && exit 1

Options="$Options $ReindexOption"

studydir=`$REPOSITORYHANDLER_HOME/bin/locateResource $REPOSITORY_DATA_DICOM $Study`
[ $? -ne 0 ] && exit 1

if [ "$BackGround" = "true" ] ; then
	[ "$MissingOnly" = "true" ] && Options="$Options -m"
	echo "$0 $Options \"$Study\" >/dev/null 2>/dev/null" | at now
	exit 0
fi

if [ "$MissingOnly" = "true" ] ; then
	echo "select FNAME from $OBJECTTBL, $STUDYTBL where STYIUID='$Study' AND Dcstudy_D='no';" | $MYSQL_HOME/bin/mysql -N $DBNAME | sed -e 's;^;\^;' -e 's;$;\$;' > $TMP/reindex.$$.p
	files=`ls $studydir | grep -v -f $TMP/reindex.$$.p`
	rm $TMP/reindex.$$.p
else
	files=`ls $studydir`
fi

# echo "$files"

Date=$(date +"%Y%m%d%H%M%S")
for File in $files ; do
	$UTILS_HOME/bin/storeDICOMFile $Options -f "$File" -s "$Study" -D "DELTA_STORESCP_REG_REINDEX"
done

exit 0
