<%--
 * Component: checkintegrity
 *
 * Description:
 *    Fixes storestate link for a study toward the archive
 *
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
 *
--%><%@
	page import="java.io.*, java.util.*, imagemed.dotcom.*, imagemed.checkintegrity.*,
			imagemed.jsputil.DotcomToolbox, imagemed.imsession.*, imagemed.util.*"

%><%@
	page errorPage="../main/exceptionHandler.jsp"

%><%!

	/**
	 * Prints result to output writer in a processable format
	 *
	 * @param out      Output writer to print result on
	 * @param result   Result to be written
	 * @param message  Additional message to be written if any 
	 */
	static void printResult(JspWriter out, String result, String message) throws IOException {
		out.println("#RESULT: " + result);
		if (message != null) {
			out.println("#MESSAGE: " + message);
		}
	}

%><%
	response.setContentType("text/plain");

	//IMSession is = new IMSession(request, response, out);

	// Stud Instance UID of the study to be fixed
	String parStudy         = request.getParameter("cStudy");

	// Process Mode for the study if no study directory / storestate.rec file exists
	String parProcessMode   = request.getParameter("cProcessMode");

	// Can be 'owner' (= add the peer to the owner branch) or 'staged' (= add the peer to the staged branch)
	String parOwnerStatus    = request.getParameter("cOwnerStatus");

	// Archive device to be set in newly created storestate.rec file
	String parArchiveDevice = request.getParameter("cArchiveDevice");

	// ID of the device the study to be archived if there is any archive configured
	String parStudyTopDevice = request.getParameter("cStudyTopDevice");

	String peerId = null;
	try {
		Properties prpDevice = DotcomToolbox.checkClient(request.getRemoteAddr());
		peerId = prpDevice.getProperty("ID");
	}
	catch (Throwable th) {
	}

	if (peerId == null) {
		printResult(out, "ERROR", "Peer is not recognized");
		return;
	}

	if (parStudy == null) {
		printResult(out, "ERROR", "Missing parameter: cStudy");
		return;
	}

	if (parOwnerStatus == null) {
		printResult(out, "ERROR", "Missing parameter: cOwnerStatus");
		return;
	}
	else if (!"owner".equals(parOwnerStatus) && !"staged".equals(parOwnerStatus)) {
		printResult(out, "ERROR", "Invalid value for cOwnerStatus: " + parOwnerStatus);
		return;
	}
	
	Vector<String> modStorestate = new Vector<String>();
	
	StoreState storestate = new StoreState(parStudy);
	if (! storestate.load()) {
		// storestate.rec file does not yet exist
		storestate.setMode(StoreState.CREATE_ONLY);

		// First try to fix the storestate on the route toward study top:
		String resultOnRoute = null;
		String nextDev = null;
		if (parStudyTopDevice != null) {
			nextDev = DotcomConfig.getConfig().getServerNameTowards(parStudyTopDevice);
		}

		if (nextDev != null) {
			StorestateLinkRepairer linkRepairer = new StorestateLinkRepairer(out, parStudy, parStudyTopDevice);
			resultOnRoute = linkRepairer.addCurrentDeviceToPeer(nextDev, parProcessMode, parArchiveDevice, parOwnerStatus);
		}
		else if ("staged".equals(parOwnerStatus)) {
			// We are the study top device, peer thinks that we are the owner: set StudyOwner
			modStorestate.add("--owner");
			modStorestate.add("yes");
		}

		if ("owner".equals(parOwnerStatus)) {
			// Peer is the owner: set OwnerDevice
			modStorestate.add("--setowner");
			modStorestate.add(peerId);
		}

		
		if (null != resultOnRoute) {
			if ("EXISTS_OWNERDEVICE_SET".equals(resultOnRoute) && "staged".equals(parOwnerStatus)) {
				// Peer is to be set to staged, and parent (study top) thinks we are the owner
				modStorestate.add("--owner");
				modStorestate.add("yes");
			}
			else if (!"OK".equals(resultOnRoute)) {
				printResult(out, "ERROR", "study already exists toward study top [" + nextDev + ": " + resultOnRoute + "]");
				return;
			}
		}
		
		if (parProcessMode != null) {
			modStorestate.add("--processmode");
			modStorestate.add(parProcessMode);
		}

		if (parArchiveDevice != null) {
			modStorestate.add("--archive");
			modStorestate.add(parArchiveDevice);
		}
	}
	else {
		// storestate.rec file already exists: check if we can do the fix
		if ("owner".equals(parOwnerStatus)) {
			if ("yes".equals(storestate.getAttribute("StudyOwner"))) {
				printResult(out, "EXISTS_STUDYOWNER_SET", "Peer can not be set as owner [current device is the owner]");
				return;
			}
			String ownerDevice = storestate.getAttribute("OwnerDevice", "NULL");
			if (!"NULL".equals(ownerDevice)) {
				// Owner device is set
				if (peerId.equals(ownerDevice)) {
					// peer is already the owner - we are ready
					printResult(out, "OK", null);
					return;
				}

				printResult(out, "EXISTS_OWNERDEVICE_SET", "Peer can not be set as owner [owner device is already set to " +
						ownerDevice + "]");
				return;
			}

			modStorestate.add("--setowner");
			modStorestate.add(peerId);
		}
		else {
			// parOwnerStatus is staged (value has already been validated)
			String ownerDevice = storestate.getAttribute("OwnerDevice");
			if (peerId.equals(ownerDevice)) {
				printResult(out, "EXISTS_AS_OWNER", "Peer can not be set as staged [it is set to be the owner]");
				return;
			}

			modStorestate.add("--setstaged");
			modStorestate.add(peerId);
		}
	}

	if (!modStorestate.isEmpty()) {
		storestate.modify(modStorestate);
		// modify reloads storestate.rec
	}

	//Check if received out of StudyTop direction instead of child (versus parent)
	String parent = storestate.getNextToStudyTop( DotcomConfig.selfDevice() );
	if (!peerId.equals(parent)) {
		// Add child_<device> reference to STUDYDIR
		ReferenceCounter.createReference("STUDYDIR", parStudy, "child_" + peerId);
	}

	printResult(out, "OK", null);
%>

