#!/bin/sh
#
# Component: qr
#
# Description:
#     Sends Query/Retrieve Find requests to DICOM device
#
# usage:
#  find.sh [ -P | -S | -O ] [-l <limit>] -h <hostname> -f <dumpfile>
#
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="qrfind"

DATE=`date +"%Y%m%d%H%M%S"`

file=""
host=""
model="-S"
limit=""

while getopts 'PSOh:f:l:' OPT; do
	case $OPT in
		P) model="-P" ;;
		S) model="-S" ;;
		O) model="-O" ;;
		h) host="$OPTARG" ;;
		f) file="$OPTARG" ;;
		l) limit="--limit $OPTARG" ;;
		*) echo "Invalid_Parameter:$OPT" ; exit 1 ;;
	esac 
done

[ -z "$file" -o -z "$host" ] && exit 2
[ ! -f "$file" ] && exit 3
 
dcmfile=$TMP/find.$DATE.$$.dcm

$DCMTK_HOME/bin/dump2dcm $file $dcmfile >/dev/null
res=$?

[ $res -ne 0 -o ! -f "$dcmfile" ] && exit 4

. $DICOM_VAR/pb-scp.cfg

[ -z "$AE_TITLE" ] && AE_TITLE="$DICOM_AE_TITLE"

echo "select HOST, PORT, AE, PROTOCOL from $TARGETTBL where ID='$host';" |
$MYSQL_HOME/bin/mysql -N $DBNAME |
if read fhost fport fae fprotocol ; then

	TIME_ZONE=""
	TZ_OPT=""
	[ -f "$DICOM_VAR/pb-scp.cfg" ] && . "$DICOM_VAR/pb-scp.cfg"
	[ -f "$DICOM_VAR/devices/$host.cfg" ] && . "$DICOM_VAR/devices/$host.cfg"

	$LOGGER -p $LOG_FACILITY.debug -t "$TAG" "Receive: [$RECEIVE_TIMEOUT] Send: [$SEND_TIMEOUT]"

	[ -n "$RECEIVE_TIMEOUT" ] && RECV_OPT=" -rt $RECEIVE_TIMEOUT"
	[ -n "$SEND_TIMEOUT" ] && SEND_OPT=" -st $SEND_TIMEOUT"
	[ -n "$CONNECTION_TIMEOUT" ] && CONN_OPT=" -ct $CONNECTION_TIMEOUT"
	
	[ -n "${TIME_ZONE}" ] && TZ_OPT=" -tz ${TIME_ZONE}"
	
	calledAE=""
	[ -n "$fae" -a "*" != "$fae" ] && calledAE=" --call $fae"

	callingAE="-aet $AE_TITLE"

	TLS_OPT=""
	[ "$fprotocol" = "S" ] && TLS_OPT="+tls $SSL_SITE_KEY $SSL_SITE_CERT -ic +ps"

	if [ "$fprotocol" = "S" ] ; then
		$OPENSSL_PASS
	fi | \
	$DICOM_HOME/bin/findscu $model $limit $TLS_OPT $RECV_OPT $SEND_OPT $CONN_OPT ${TZ_OPT} +xA $callingAE $calledAE $fhost $fport $dcmfile
	ret=$?
	rm $dcmfile

	$LOGGER -p $LOG_FACILITY.debug -t "$TAG" "$DICOM_HOME/bin/findscu $model $limit $TLS_OPT $RECV_OPT $SEND_OPT $CONN_OPT ${TZ_OPT} +xA $callingAE $calledAE $fhost $fport $dcmfile  [returns: $ret]"

	exit $ret

else
	exit 5
fi
